@@ -1,19 +1,20 @@
-; Aisleriot - klondike.scm
-; Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
+; AisleRiot - klondike.scm
+; Copyright (C) 1998, 2003 Jonathan Blandford <jrb@mit.edu>
 ;
-; This game is free software; you can redistribute it and/or
-; modify it under the terms of the GNU Library General Public
-; License as published by the Free Software Foundation; either
-; version 2 of the License, or (at your option) any later version.
+; This game is free software; you can redistribute it and/or modify
+; it under the terms of the GNU General Public License as published by
+; the Free Software Foundation; either version 2, or (at your option)
+; any later version.
 ;
-; This library is distributed in the hope that it will be useful,
+; This program is distributed in the hope that it will be useful,
 ; but WITHOUT ANY WARRANTY; without even the implied warranty of
-; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-; Library General Public License for more details.
+; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+; GNU General Public License for more details.
 ;
-; You should have received a copy of the GNU Library General Public
-; License along with this library; if not, write to the Free
-; Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+; You should have received a copy of the GNU General Public License
+; along with this program; if not, write to the Free Software
+; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+; USA
 
 (define deal-three #f)
 
@@ -26,12 +27,17 @@
 
 (define (new-game)
   (initialize-playing-area)
+  (set-ace-low)
 
   (make-standard-deck)
   (shuffle-deck)
   
   (add-normal-slot DECK)
-  (add-partially-extended-slot '() right 3)
+
+  (if deal-three
+      (add-partially-extended-slot '() right 3)
+      (add-normal-slot '()))
+
   (add-blank-slot)
   (add-normal-slot '())
   (add-normal-slot '())
@@ -50,9 +56,24 @@
   
   (map flip-top-card tableau)
 
+  (give-status-message)
+
   (list 7 3)
 )
 
+(define (give-status-message)
+  (set-statusbar-message (string-append (get-stock-no-string)
+					"   "
+					(get-redeals-string))))
+
+(define (get-redeals-string)
+  (string-append (_"Redeals left:") " "
+		 (number->string (- 2 FLIP-COUNTER))))
+
+(define (get-stock-no-string)
+  (string-append (_"Stock left:") " " 
+		 (number->string (length (get-cards 0)))))
+
 (define (button-pressed slot-id card-list)
   (and (or (> slot-id 1)
 	   (and (= slot-id 1)
@@ -86,41 +107,39 @@
 		    (and (= (get-suit (get-top-card end-slot))
 			    (get-suit (car card-list)))
 			 (= (get-value (get-top-card end-slot)) 
-				(- (get-value (car card-list)) 1))))))
+			    (- (get-value (car card-list)) 1))))))
        (complete-transaction start-slot card-list end-slot)))
 
 (define (button-clicked start-slot)
-  (or (and (= start-slot stock)
-	   (flip-stock stock waste 2 (if deal-three 3 1)))
-      (and (member start-slot (cons waste tableau))
-	   (not (empty-slot? start-slot))
-	   (let* ((card (get-top-card start-slot))
-		  (suit (get-suit card))
-		  (value (get-value card)))
-	     (let ((end-slot 
-		    (cond ((if (empty-slot? 2)
-			       (= ace value)
-			       (= suit (get-suit (get-top-card 2)))) 2)
-			  ((if (empty-slot? 3)
-			       (= ace value)
-			       (= suit (get-suit (get-top-card 3)))) 3)
-			  ((if (empty-slot? 4)
-			       (= ace value)
-			       (= suit (get-suit (get-top-card 4)))) 4)
-			  ((if (empty-slot? 5)
-			       (= ace value)
-			       (= suit (get-suit (get-top-card 5)))) 5)
-			  (#t #f))))
-	       (and end-slot
-		    (or (= ace value)
-			(= (get-value (get-top-card end-slot)) (- value 1)))
-		    (remove-card start-slot)
-		    (complete-transaction start-slot (list card) end-slot)))))))
+  (and (= start-slot stock)
+       (flip-stock stock waste 2 (if deal-three 3 1))))
+
+(define (button-double-clicked start-slot)
+  (and (member start-slot (cons waste tableau))
+       (not (empty-slot? start-slot))
+       (let* ((card (get-top-card start-slot))
+	      (suit (get-suit card))
+	      (value (get-value card)))
+	 (let ((end-slot 
+		(cond ((if (empty-slot? 2)
+			   (= ace value)
+			   (= suit (get-suit (get-top-card 2)))) 2)
+		      ((if (empty-slot? 3)
+			   (= ace value)
+			   (= suit (get-suit (get-top-card 3)))) 3)
+		      ((if (empty-slot? 4)
+			   (= ace value)
+			   (= suit (get-suit (get-top-card 4)))) 4)
+		      ((if (empty-slot? 5)
+			   (= ace value)
+			   (= suit (get-suit (get-top-card 5)))) 5)
+		      (#t #f))))
+	   (and end-slot
+		(or (= ace value)
+		    (= (get-value (get-top-card end-slot)) (- value 1)))
+		(remove-card start-slot)
+		(complete-transaction start-slot (list card) end-slot))))))
 
-; The C still has problems detecting button double clicks ... 
-					 
-(define (button-double-clicked slot)
-  #f)
 
 ; Global variables used in searching (keeping it simple):
 
@@ -146,13 +165,13 @@
 (define (is-ace? slot-id)
   (and (not (empty-slot? slot-id))
        (= ace (get-value (get-top-card slot-id)))
-       (list 2 (get-name (get-top-card slot-id)) "an empty slot" )))
+       (list 2 (get-name (get-top-card slot-id)) (_"an empty slot" ))))
 
 (define (shiftable? slot-id2)
   (and (not (= slot-id2 slot-id1))
        (if (empty-slot? slot-id2)
 	   (and (= value king)
-		(list 2 (get-name card) "an empty slot"))
+		(list 2 (get-name card) (_"an empty slot")))
 	   (and (= (get-value (get-top-card slot-id2)) (+ 1 value))
 		(not (= (get-color (get-top-card slot-id2)) color))
 		(list 1 (get-name card) (get-name (get-top-card slot-id2)))))))
@@ -174,7 +193,7 @@
 (define (addable? slot-id)
   (if (empty-slot? slot-id)
       (and (= (get-value card) king)
-	   (list 2 (get-name card) "an empty slot" ))
+	   (list 2 (get-name card) (_"an empty slot" )))
       (and (= (get-value (get-top-card slot-id)) (+ 1 (get-value card)))
 	   (not (= (get-color (get-top-card slot-id)) (get-color card)))
 	   (list 1 (get-name card) (get-name (get-top-card slot-id))))))
@@ -186,12 +205,14 @@
 	   (set! card (get-top-card waste))
 	   (or-map addable? tableau))
       (or-map ploppable? foundation)
-      (and (or (and (< FLIP-COUNTER 3)
+      (and (or (and (< FLIP-COUNTER 2)
 		    (not (empty-slot? waste)))
 	       (not (empty-slot? stock))) 
-	   (list 0 "Deal a new card from the deck"))
+	   (list 0 (_"Deal a new card from the deck")))
 ; FIXME: need to give proper hints for this case too ...
-      (list 0 "Try moving cards down from the foundation")))
+      (and (not (and-map empty-slot? '(2 3 4 5)))
+           (list 0 (_"Try moving cards down from the foundation")))
+      (list 0 (_"No hint available right now"))))
 
 (define (game-won)
   (and (= 13 (length (get-cards 2)))
@@ -208,10 +229,11 @@
 ; so we must NOT report game-over when they run out.
 
 (define (game-over)
+  (give-status-message)
   (not (game-won)))
 
 (define (get-options)
-  (list (list "Three card deals" deal-three)))
+  (list (list (_"Three card deals") deal-three)))
 
 (define (apply-options options)
   (set! deal-three (cadar options)))
